@@ -17,10 +17,16 @@
 /* Define if the debug option is enabled. */
 #undef DEBUG
 
+#undef HAVE_DB2
+
+#undef HAVE_DB3
+
 #undef LINUX
 
 #undef FREEBSD
 
+#undef NETBSD
+
 #undef OPENBSD
 
 #undef SOLARIS
